# Security Policy

## Reporting a Vulnerability

Open an issue on GitHub using [the vulnerability template](https://github.com/Componolit/RecordFlux/issues/new?labels=vulnerability&template=vulnerability.md). In addition to the `vulnerability` tag (which should be added automatically) also add tags for the versions that you know are affected.

We will get back to you within a working day to discuss the next steps.

## Confidential Reporting

If you would like to report a security vulnerability confidentially, please send an email to [recordflux_remove_this_text_including_first_underscore@componolit.com](mailto:recordflux_remove_this_text_including_first_underscore@componolit.com) (make sure to change the address as described).

## Supported Versions

We will fix security vulnerabilities for the latest released version and the `main` branch.
